
import numpy as np
from os.path import splitext
import matplotlib.pyplot as plt
from scipy.optimize import curve_fit
import sys

plt.rc('font', size=10)
plt.figure(0)

def exp(x, a, b, c):
    return a*np.exp(-b*x) + c

def dofit(funct, xdata, ydata, error=[], type='curve_fit'):
    guess=[max(ydata), 0.001, min(ydata) ]
    if type=='curve_fit':
        popt, pcov=curve_fit(funct, xdata, ydata, guess)
    elif type=='polyfit':
        popt= poly.polyfit(xdata, ydata, 3)
    return popt, pcov


def fitNplot( Data=[( 'p.txt', 15. )] ):
    
    cols=['k', 'b', 'r', 'g', 'y']
    rates, errors, labels=[], [], []
    for i, dset in enumerate(Data):
        print()
        fname =dset[0]
        label =dset[1]
        time  =dset[2]
        c=cols[i]
        
        peak = np.genfromtxt(fname ,comments='#', dtype='str', usecols=(0) )[0]
        data = np.genfromtxt(fname ,comments='#', usecols=(1,2,3,4) )
        
        specs =data[:,0]
        xppm  =data[:,1]
        yppm  =data[:,2]
        inten =data[:,3]
        
        dxppm=xppm-xppm[0]
        dyppm=yppm-yppm[0]
        dinten=inten/inten[0]
    
        t=np.arange(1., len(specs)+1, 1)*time
        error=0.001
        
        try:
            fit_x    =dofit(exp, t, dxppm, error=error)
            params_x =fit_x[0]
            fit_errors_x=np.sqrt(np.diag(fit_x[1]))
            print('Peak: %s X_PPM a: %.3f +/- %.3f  b:  %.4f +/- %.4f   c:  %.3f +/- %.3f'  %(fname, params_x[0], fit_errors_x[0], params_x[1], fit_errors_x[1], params_x[2], fit_errors_x[2] ) )

            fit_y    =dofit(exp, t, dyppm, error=error)
            params_y =fit_y[0]
            fit_errors_y=np.sqrt(np.diag(fit_y[1]))
            print('Peak: %s Y_PPM a: %.3f +/- %.3f  b:  %.4f +/- %.4f   c:  %.3f +/- %.3f'  %(fname, params_y[0], fit_errors_y[0], params_y[1], fit_errors_y[1], params_y[2], fit_errors_y[2] ) )

            fit_inten    =dofit(exp, t, dinten, error=error)
            params_inten =fit_inten[0]
            fit_errors_inten=np.sqrt(np.diag(fit_inten[1]))
            print('Peak: %s Intensity a: %.3f +/- %.3f  b:  %.4f +/- %.4f   c:  %.3f +/- %.3f'  %(fname, params_inten[0], fit_errors_inten[0], params_inten[1], fit_errors_inten[1], params_inten[2], fit_errors_inten[2] ) )
            
        except RuntimeError:
            print('Fit failed')
            params_x, params_y, params_inten=[0]*3, [0]*3, [0]*3
            fit_errors_x, fit_errors_y, fit_errors_inten=[0]*3, [0]*3, [0]*3
        
        newxaxis=np.arange(min(t), max(t), 0.1)
        
        ax=plt.subplot(221)
        fitted_curve=exp(newxaxis, *params_x)
        plt.xlabel('Time (min)')
        plt.ylabel('dX_PPM')
        ax.plot(t, dxppm, '%so'%c, markersize=5, label='%s_%s: %.4f '%(label, peak, params_x[1]))
        ax.plot(newxaxis, fitted_curve, '%s-'%c, linewidth=3)
        #plt.ylim([-0.1,1.2])
        #plt.legend()       
        
        ax=plt.subplot(222)
        fitted_curve=exp(newxaxis, *params_y)
        plt.xlabel('Time (min)')
        plt.ylabel('dY_PPM')
        ax.plot(t, dyppm, '%so'%c, markersize=5, label='%s_%s: %.4f '%(label, peak, params_y[1]))
        ax.plot(newxaxis, fitted_curve, '%s-'%c, linewidth=3)
        
        #plt.ylim([-0.1,1.2])
        #plt.yticks(np.arange(0.0, 1.01, 0.5))       
        #plt.xticks(np.arange(0.0, max(delays)+0.1,   30.   ))   
        #plt.xlim([0,max(delays)+10])
        #plt.xticks(delays)   
        #plt.title('Peak %s' %peak)
        plt.legend()        
        
        ax=plt.subplot(223)
        fitted_curve=exp(newxaxis, *params_inten)
        plt.xlabel('Time (min)')
        plt.ylabel('dInten')
        #plt.errorbar(delays, inten, yerr=error, fmt='none')
        plt.plot(t, dinten, '%so'%c, markersize=5, label='%s_%s: %.4f '%(label, peak, params_inten[1]))
        plt.plot(newxaxis, fitted_curve, '%s-'%c, linewidth=3)      
        #plt.ylim([-0.1,1.2])
        #plt.legend()        
        
        rates.append(  [ params_x[1], params_y[1], params_inten[1]]) 
        errors.append( [ fit_errors_x[1], fit_errors_y[1], fit_errors_inten[1]] )
        labels.append('%s_%s '%(label, peak) )
    
    ax=plt.subplot(224)
    X = np.arange(len(Data))
    width = 0.5
    rates, errors=np.array(rates).T, np.array(errors).T
    ax.set_xticks(X- width)
    ax.set_xticklabels(labels, rotation=45)
    plt.ylabel('Rate (1/min)')
    
    ax.errorbar(X - width/2, rates[0], yerr=errors[0], color='orange',  fmt='none')
    #ax.errorbar(X + 0.00, rates[1], yerr=errors[1], color='r',  fmt='none')
    ax.errorbar(X + width/2, rates[2], yerr=errors[2], color='gray',  fmt='none')

    ax.bar(X - width/2, rates[0], color = 'orange', width = 0.25, label='X_PPM')
    #ax.bar(X + 0.00, rates[1], color = 'r', width = 0.25, label='Y_PMM')
    ax.bar(X + width/2, rates[2], color = 'gray', width = 0.25, label='Inten')
    ax.legend() 
   
    
    plt.tight_layout()
    plt.savefig('./fit_Mscs_p_k.pdf', transparent=True)
    plt.show()
                   
fitNplot( Data=[ ( './220318_Mscs_D67_R1_txt/p.txt', 'Mscs',  31.0 ),   
                 ( './220318_Mscs_D67_R1_txt/m.txt', 'Mscs',  31.0 ),
                 #( './220318_Mscs_D67_R1_txt/O2.txt', 'Mscs',  31.0 ),
                 #( './220318_Mscs_D67_R1_txt/k.txt', 'Mscs',  31.0 ),
                 ( './cd_1/p.txt', 'EmptyCD1',  11.3 ) ,
                 ( './cd_1/m.txt', 'EmptyCD1', 11.3 ),
                 #( './cd_1/o2.txt', 'EmptyCD1', 11.3 )
                 #( './cd_2/p.txt', 'EmptyCD2',  11.3 ) ,
                 #( './cd_2/m.txt', 'EmptyCD2', 11.3 ),
                 #( './cd_2/o2.txt', 'EmptyCD2', 11.3 ),
                 #( './cd_3/p.txt', 'EmptyCD3', 11.3 )
                 
                 ])


#( './220318_Mscs_D67_R1_txt/p.txt', 31.0 )
#11.3
