#!/bin/csh

if ($#argv <1) then
  echo "no input peaklist is given!"
  echo "Exiting"
  exit
endif

if ($1 == "-h") then
 echo
 echo "follow chemical shift changes from a reference peaklist within specified ranges" 
 echo
 echo "usage peak.com name_of_ref_peaklist"
 echo "specify a ref spectrum and choose output as Hz or PPM"
 exit
endif

set infile   = $1            # input peaklist
set ft2      = ./1/test.ft2  # ref spectrum check
set XrangeHz = 80            # Hz
set YrangeHz = 80            # Hz
set obsX     = X_PPM         # X_HZ X_PPM
set obsY     = Y_PPM         # Y_HZ Y_PPM
set inten    = HEIGHT        # HEIGHT VOL

#set specs = `seq 100 132`
#set specs = ( 1 3 6 9 12 15 18 21) 
set specs = ( 1)

getTabCol.tcl -in $1 -var ASS X_AXIS Y_AXIS>temp.txt

#goto P1  #uncomment to only do the printing 

set noise = `specStat.com -in $ft2 -x1 0% -xn 100% -y1 0% -yn 100% -stat vEstNoise -brief`

if (-d tab) rm -r ./tab
mkdir tab

if (-d txt) rm -r ./txt
mkdir txt

set xObs = `showhdr -in $ft2  -verb  | grep 'OBS MHz' | awk '{print $3}'`
set yObs = `showhdr -in $ft2  -verb  | grep 'OBS MHz' | awk '{print $4}'`

set HzPerpointX = `showhdr -in $ft2  -verb  | grep 'Hz/POINT' | awk '{print $2}'`
set HzPerpointY = `showhdr -in $ft2  -verb  | grep 'Hz/POINT' | awk '{print $3}'`

echo "Hz/point X:"  $HzPerpointX, "Hz/point Y:"  $HzPerpointY

set XrangePoints = `echo "scale = 10; $XrangeHz / $HzPerpointX " | bc`
set YrangePoints = `echo "scale = 10; $YrangeHz / $HzPerpointY " | bc`


foreach peak ( "`cat temp.txt`" )
  set ass = `echo $peak | awk '{print $1}'`
  set x   = `echo $peak | awk '{print $2}'`
  set y   = `echo $peak | awk '{print $3}'`
  
  set x1 = `echo "scale = 0;   $x -  ( $XrangePoints ) / 2 "  | bc`
  set xN = `echo "scale = 0;   $x +  ( $XrangePoints ) / 2 "  | bc`
  
  set y1 = `echo "scale = 0;   $y -  ( $YrangePoints ) / 2 "  | bc`
  set yN = `echo "scale = 0;   $y +  ( $YrangePoints ) / 2 "  | bc` 
  
  echo $ass $x1 $xN $y1 $yN

  foreach spec ( $specs ) 
    echo
    echo  Working on Peak $ass spec $spec
    set name = `printf %03d $spec`
  
    ./peak.tcl ./$spec/test.ft2 ./tab/$ass'_'$name.tab $x1 $xN $y1 $yN $noise
  
  end  
end

P1:
echo 'Extracting peaks'
foreach peak ( "`cat temp.txt ` " )
   set ass = `echo $peak | awk '{print $1}'` 
   foreach spec ( $specs ) 
      set name   = `printf %03d $spec`
      set xpeak  = `getTabCol.tcl -in ./tab/$ass'_'$name.tab -var ASS $obsX  | awk '{print $2}'`
      set ypeak  = `getTabCol.tcl -in ./tab/$ass'_'$name.tab -var ASS $obsY  | awk '{print $2}'`
      set height = `getTabCol.tcl -in ./tab/$ass'_'$name.tab -var ASS $inten | awk '{print $2}'`
      echo $ass $spec $xpeak $ypeak $height | grep -v None >> ./txt/$ass.txt
  end
end

rm temp.txt









